@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -62,9 +62,9 @@ def set_debug(debugmode):
         DEBUG |= debugmode
 
 class debugged(object):
-    """repository debugging context manager / decorator
+    """Context manager and decorator to help debug the repository.
 
-    Can be used either as a context manager:
+    It can be used either as a context manager:
 
     >>> with debugged(server.DBG_RQL | server.DBG_REPO):
     ...     # some code in which you want to debug repository activity,
@@ -77,8 +77,8 @@ class debugged(object):
     ...     # some code in which you want to debug repository activity,
     ...     # seing information about RQL being executed an repository events
 
-    debug mode will be reseted at its original value when leaving the "with"
-    block or the decorated function
+    The debug mode will be reset to its original value when leaving the "with"
+    block or the decorated function.
     """
     def __init__(self, debugmode):
         self.debugmode = debugmode
@@ -121,7 +121,7 @@ def init_repository(config, interactive=True, drop=False, vreg=None):
     with the minimal set of entities (ie at least the schema, base groups and
     a initial user)
     """
-    from cubicweb.dbapi import in_memory_cnx
+    from cubicweb.dbapi import in_memory_repo_cnx
     from cubicweb.server.repository import Repository
     from cubicweb.server.utils import manager_userpasswd
     from cubicweb.server.sqlutils import sqlexec, sqlschema, sqldropschema
@@ -129,7 +129,6 @@ def init_repository(config, interactive=True, drop=False, vreg=None):
     # on connection
     config.creating = True
     config.consider_user_state = False
-    config.set_language = False
     # only enable the system source at initialization time
     repo = Repository(config, vreg=vreg)
     schema = repo.schema
@@ -182,10 +181,11 @@ def init_repository(config, interactive=True, drop=False, vreg=None):
     session.execute('SET X owned_by U WHERE X is IN (CWGroup,CWSource), U eid %(u)s',
                     {'u': admin.eid})
     session.commit()
+    session.close()
     repo.shutdown()
     # reloging using the admin user
     config._cubes = None # avoid assertion error
-    repo, cnx = in_memory_cnx(config, login, password=pwd)
+    repo, cnx = in_memory_repo_cnx(config, login, password=pwd)
     repo.system_source.eid = ssource.eid # redo this manually
     # trigger vreg initialisation of entity classes
     config.cubicweb_appobject_path = set(('entities',))
@@ -205,12 +205,10 @@ def init_repository(config, interactive=True, drop=False, vreg=None):
     repo.system_source.init_creating()
     cnx.commit()
     cnx.close()
-    session.close()
     repo.shutdown()
     # restore initial configuration
     config.creating = False
     config.consider_user_state = True
-    config.set_language = True
     print '-> database for instance %s initialized.' % config.appid
 
 
