@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -117,7 +117,9 @@ class BreadCrumbEntityVComponent(basecomponents.HeaderComponent):
     link_template = u'<a href="%s">%s</a>'
     first_separator = True
 
-    def render(self, w):
+    # XXX support kwargs for compat with other components which gets the view as
+    # argument
+    def render(self, w, **kwargs):
         entity = self.cw_rset.get_entity(0, 0)
         adapter = ibreadcrumb_adapter(entity)
         view = self.cw_extra_kwargs.get('view')
@@ -178,7 +180,9 @@ class BreadCrumbETypeVComponent(BreadCrumbEntityVComponent):
 class BreadCrumbAnyRSetVComponent(BreadCrumbEntityVComponent):
     __select__ = basecomponents.HeaderComponent.__select__ & any_rset()
 
-    def render(self, w):
+    # XXX support kwargs for compat with other components which gets the view as
+    # argument
+    def render(self, w, **kwargs):
         w(u'<span id="breadcrumbs" class="pathbar">')
         if self.first_separator:
             w(self.separator)
@@ -192,7 +196,7 @@ class BreadCrumbView(EntityView):
     def cell_call(self, row, col, **kwargs):
         entity = self.cw_rset.get_entity(row, col)
         desc = xml_escape(uilib.cut(entity.dc_description(), 50))
-        # XXX remember camember : tags.a autoescapes !
+        # NOTE remember camember: tags.a autoescapes
         self.w(tags.a(entity.view('breadcrumbtext'),
                       href=entity.absolute_url(), title=desc))
 
